<?php
// $Id: global_avatar.admin.inc,v 1.1 2009/11/25 20:13:38 cpliakas Exp $

/**
 * @file
 * Administrative settings callbacks for the Global Avatar module.
 */

/**
 * Administrative settings for the Global Avatar module.
 *
 * @return
 *   A FAPI array od admin settings.
 */
function global_avatar_admin_settings() {
  $form = array();

  $form['global'] = array(
    '#type' => 'fieldset',
    '#title' => t('Global settings'),
    '#description' => t('Settings that are reflected across the multisite network.'),
  );

  $form['global']['enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use this site\'s picture image path as the global avatar directory'),
    '#default_value' => (int)global_avatar_enabled_get(),
    '#description' => t(
      'Although avatars can be spread across different directories in a multisite installation, it may be advantageous to store them all in a single location. Select this checkbox to store all avatars in this site\'s <a href="@user-settings-page">picture image path</a>.',
      array('@user-settings-page' => url('admin/user/settings'))
    ),
  );

  // If another site's picture image path is set as the global avatar directory , displays.
  if (!file_check_location(global_avatar_path_get(), file_directory_path())) {
    $form['global']['enabled-desc'] = array(
      '#value' => t(
        'The picture image path in the <strong>@site</strong> site is currently set as the global avatar directory.',
        array('@site' => db_result(db_query('SELECT site_name FROM {global_avatar} WHERE enabled = 1')))
      ),
    );
  }

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
    '#weight' => 50,
  );

  return $form;
}

/**
 * Modified the shared database.
 *
 * @param $form
 *   A nested array of form elements that comprise the form.
 * @param &$form_state
 *   A keyed array containing the current state of the form.
 * @return
 *   NULL
 */
function global_avatar_admin_settings_submit($form, &$form_state) {
  if ($form_state['values']['enabled']) {
    global_avatar_enabled_set(TRUE);
  }
  else {
    global_avatar_enabled_set(FALSE);
  }
}
